slepc-3.18.0 2022-10-01
Report Typos and Errors

# DSSetRefined

Sets a flag to indicate that refined vectors must be computed.

### Synopsis

    #include "slepcds.h"
    PetscErrorCode DSSetRefined(DS ds,PetscBool ref)

Logically Collective on ds

### Input Parameters

| ds | - the direct solver context
| ref | - a boolean flag

### Notes

Normally the vectors returned in DS_MAT_X are eigenvectors of the projected matrix. With this flag activated, DSVectors() will return the right singular vector of the smallest singular value of matrix \tilde{A}-theta*I, where \tilde{A} is the extended (n+1)xn matrix and theta is the Ritz value. This is used in the refined Ritz approximation.

The default is PETSC_FALSE.

### See Also

DSVectors(), DSGetRefined()

### Level

advanced

### Location

src/sys/classes/ds/interface/dsbasic.c
Index of all DS routines
Table of Contents for all manual pages
Index of all manual pages